import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scaleTime,
  max, 
  format,
  timeFormat,
  extent,
  bin,
  timeMonths,
  timeWeeks,
  sum,
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 30,
  bottom: 70,
  left: 90,
};


const innerHeight =
  height - margin.top - margin.bottom;
const innerWidth =
  width - margin.left - margin.right;

const xAxisTickFormat = timeFormat("%Y");

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
  
	const xAxisLabelOffset = 55;
  const xValue = (d) => d.Date;
  const xAxisLabel = 'Date';
  
  const yAxisLabelOffset = 60;
  const yValue = (d) => d["Total Deaths, all ages"];
  const yAxisLabel = "Total Deaths, all ages";
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, d => d.y))
    .range([innerHeight, 0])
  	.nice();
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
        /> 
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset = {10}
        />
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset = {5}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        
        <text
          className="axis-label"
          textAnchor="middle"
          transform = {`translate(${-yAxisLabelOffset}, ${innerHeight/2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);